#include <QCoreApplication>
#include <QTimer>
#include "signal_emitter.h"
#include "signal_receiver.h"

int main(int argc, char *argv[])
{
  QCoreApplication app(argc, argv);

  // emitter is now a child of core application app.
  // app will delete emitter.
  signal_emitter *emitter = new signal_emitter(&app);

  // it is assigned at stack. You must declare after the parent.
  signal_receiver receiver(&app);

  // when emitter emits 'finished' signal, app will be terminated.
  QObject::connect(emitter, SIGNAL(finished()), &app, SLOT(quit()));

  // emitter-receiver connection
  QObject::connect(emitter, &signal_emitter::send,
                   &receiver, &signal_receiver::receive);

  // we emit initial 'launch()'.
  QTimer::singleShot(0, emitter, SLOT(launch()));

  // receiver should be destructed before app's destruction.
  return app.exec();
}
